/* Serial to LCD Display
 *  
 * Echos text sent over the serial port (e.g. from the Serial 
 * Monitor) to a 2004 LCD display configured with an I2C module.
 * 
 *    Uses arduino-esp32 core version 1.0.6
 * 
 *  Uses the 'LiquidCrystal_PCF8574' library
 * 
 *  --> DESIGNED FOR AN ESP32 DEV BOARD <--
 *  --> THE 2004 DISPLAY IS A 5V DEVICE <--
 *  --> REMEMBER TO USE A LEVEL SHIFTER <--
 *  -->    FOR THE SDA & SCL LINES!     <--
 *  
 */

#include <Wire.h>
#include <LiquidCrystal_PCF8574.h>

// set the number of LCD display columns, rows & the I2C module address
#define lcdColumns 20
#define lcdRows 4
#define lcdAdd 0x27         // I2C address of the I2C module on the LCD display

#define lcdSDA 25           // ESP32 pin connected to the SDA pin of the I2C module on the LCD display
#define lcdSCL 21           // ESP32 pin connected to the SCL pin of the I2C module on the LCD display

LiquidCrystal_PCF8574 lcd(lcdAdd);

void setup() {

  // introduce ourselves
  Serial.begin(115200);
  delay(50);
  Serial.println("\r\nHey there..."); Serial.print("Running sketch: "); Serial.println(__FILE__); Serial.println("");
 
  Wire.begin(lcdSDA, lcdSCL);
  
  lcd.begin(lcdColumns, lcdRows); // initialize the lcd
  lcd.setBacklight(1);
  lcd.clear();

}


void loop() {

  // when characters arrive over the serial port...
  if (Serial.available()) {
    // wait a bit for the entire message to arrive
    delay(100);
    // clear the screen
    lcd.clear();
    // read all the available characters
    while (Serial.available() > 0) {
      // display each character to the LCD
      lcd.write(Serial.read());
    }
  }

}

//  --- EOF --- \\
